@@ -1,12 +1,12 @@
-from typing import Optional
 import json
+from typing import Optional
 
-import uvicorn  # type: ignore[import]
 import typer
-
+import uvicorn  # type: ignore[import]
 from fastapi.openapi.utils import get_openapi
-from ixmp4.server import v1
+
 from ixmp4.conf import settings
+from ixmp4.server import v1
 
 from . import utils
 
@@ -15,23 +15,20 @@ app = typer.Typer()
 
 @app.command()
 def start(
-    host: Optional[str] = typer.Option(
-        "127.0.0.1",
-        help="The hostname to bind to.",
-    ),
-    port: Optional[int] = typer.Option(
-        9000,
-        help="Requested server port.",
-    ),
+    host: str = typer.Option(default="127.0.0.1", help="The hostname to bind to."),
+    port: int = typer.Option(default=9000, help="Requested server port."),
+    workers: int = typer.Option(default=1, help="How many worker threads to start."),
+    reload: bool = typer.Option(default=False, help="Wether to hot-reload."),
 ) -> None:
     """Starts the ixmp4 web api."""
-    reload = settings.mode != "production"
+    log_config = settings.get_server_logconf()
     uvicorn.run(
         "ixmp4.server:app",
         host=host,
         port=port,
         reload=reload,
-        log_config="ixmp4/conf/logging/server.conf",
+        workers=workers,
+        log_config=str(log_config.absolute()),
     )
 
 
