@@ -2,38 +2,49 @@
 This module holds a shared datastructure and interface for normalization
 between the database and api data models and repositories.
 """
-# flake8: noqa
 
 from .base import (
-    BaseModel,
     BaseMeta,
-    Retriever,
+    BaseModel,
+    BulkDeleter,
+    BulkUpserter,
     Creator,
     Deleter,
-    Lister,
-    Tabulator,
     Enumerator,
-    BulkUpserter,
-    BulkDeleter,
+    Lister,
+    Retriever,
+    Tabulator,
 )
-from .model import Model, ModelRepository
-from .run import Run, RunRepository
-from .meta import RunMetaEntry, RunMetaEntryRepository, StrictMetaValue, MetaValue
-from .scenario import Scenario, ScenarioRepository
-from .unit import Unit, UnitRepository
-from .region import Region, RegionRepository
 from .docs import Docs, DocsRepository
-
-from .iamc import (
-    Variable,
-    VariableRepository,
+from .iamc import (  # AnnualDataPoint,; SubAnnualDataPoint,; CategoricalDataPoint,
+    DataPoint,
+    DataPointRepository,
     Measurand,
     MeasurandRepository,
     TimeSeries,
     TimeSeriesRepository,
-    DataPoint,
-    #    AnnualDataPoint,
-    #    SubAnnualDataPoint,
-    #    CategoricalDataPoint,
-    DataPointRepository,
+    Variable,
+    VariableRepository,
 )
+from .meta import MetaValue, RunMetaEntry, RunMetaEntryRepository, StrictMetaValue
+from .model import Model, ModelRepository
+from .optimization import (
+    Equation,
+    EquationRepository,
+    IndexSet,
+    IndexSetRepository,
+    Parameter,
+    ParameterRepository,
+    Scalar,
+    ScalarRepository,
+    Table,
+    TableRepository,
+)
+
+# TODO for PR: avoiding name conflict here Is that okay?
+from .optimization import Variable as OptimizationVariable
+from .optimization import VariableRepository as OptimizationVariableRepository
+from .region import Region, RegionRepository
+from .run import Run, RunRepository
+from .scenario import Scenario, ScenarioRepository
+from .unit import Unit, UnitRepository
