@@ -1,4 +1,4 @@
-from typing import Protocol, Iterable
+from typing import Protocol
 
 import pandas as pd
 
@@ -30,11 +30,9 @@ class MeasurandRepository(
     base.Enumerator,
     Protocol,
 ):
-    def create(self, variable_name: str, unit__id: int) -> Measurand:
-        ...
+    def create(self, variable_name: str, unit__id: int) -> Measurand: ...
 
-    def get(self, variable_name: str, unit__id: int) -> Measurand:
-        ...
+    def get(self, variable_name: str, unit__id: int) -> Measurand: ...
 
     def get_or_create(self, variable_name: str, unit__id: int) -> Measurand:
         try:
@@ -44,10 +42,8 @@ class MeasurandRepository(
 
     def list(
         self,
-    ) -> Iterable[Measurand]:
-        ...
+    ) -> list[Measurand]: ...
 
     def tabulate(
         self,
-    ) -> pd.DataFrame:
-        ...
+    ) -> pd.DataFrame: ...
