@@ -1,6 +1,7 @@
-from typing import Iterable, Type, ClassVar
+from typing import ClassVar, Type
 
 from ixmp4.data import abstract
+
 from . import base
 
 
@@ -22,6 +23,7 @@ class DocsRepository(
     abstract.DocsRepository,
 ):
     model_class: Type[Docs]
+    enumeration_method = "GET"
 
     def get(self, dimension_id: int) -> Docs:
         return super().get(dimension_id=dimension_id)
@@ -36,8 +38,8 @@ class DocsRepository(
         )
         return Docs(**res)
 
-    def list(self, *, dimension_id: int | None = None, **kwargs) -> Iterable[Docs]:
-        return super().list(dimension_id=dimension_id)
+    def list(self, *, dimension_id: int | None = None) -> list[Docs]:
+        return super()._list(params={"dimension_id": dimension_id})
 
     def delete(self, dimension_id: int) -> None:
         super().delete(dimension_id)
