@@ -1,12 +1,13 @@
-from typing import Iterable, ClassVar
 from datetime import datetime
+from typing import ClassVar
 
 import pandas as pd
+from pydantic import Field
 
 from ixmp4.data import abstract
-from ..docs import Docs, DocsRepository
 
 from .. import base
+from ..docs import Docs, DocsRepository
 
 
 class Variable(base.BaseModel):
@@ -17,15 +18,13 @@ class Variable(base.BaseModel):
     id: int
     name: str
 
-    created_at: datetime | None
-    created_by: str | None
+    created_at: datetime | None = Field(None)
+    created_by: str | None = Field(None)
 
 
 class VariableDocsRepository(DocsRepository):
     model_class = Docs
-    prefix = (
-        "docs/iamc/variables/"  # TODO: what does this do that the below prefix doesn't?
-    )
+    prefix = "docs/iamc/variables/"
 
 
 class VariableRepository(
@@ -36,11 +35,10 @@ class VariableRepository(
 ):
     model_class = Variable
     prefix = "iamc/variables/"
-    enumeration_method = "PATCH"
 
-    def __init__(self, client, *args, **kwargs) -> None:
-        super().__init__(client, *args, **kwargs)
-        self.docs = VariableDocsRepository(self.client)
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.docs = VariableDocsRepository(self.backend)
 
     def create(
         self,
@@ -51,11 +49,11 @@ class VariableRepository(
     def get(self, name: str) -> Variable:
         return super().get(name=name)
 
-    def list(self, *args, **kwargs) -> Iterable[Variable]:
-        return super().list(*args, **kwargs)
+    def enumerate(self, **kwargs) -> list[Variable] | pd.DataFrame:
+        return super().enumerate(**kwargs)
 
-    def tabulate(self, *args, **kwargs) -> pd.DataFrame:
-        return super().tabulate(*args, **kwargs)
+    def list(self, **kwargs) -> list[Variable]:
+        return super()._list(json=kwargs)
 
-    def enumerate(self, *args, **kwargs) -> Iterable[Variable] | pd.DataFrame:
-        return super().enumerate(*args, **kwargs)
+    def tabulate(self, **kwargs) -> pd.DataFrame:
+        return super()._tabulate(json=kwargs)
