@@ -1,9 +1,11 @@
-from typing import Iterable, ClassVar
 from datetime import datetime
+from typing import ClassVar
 
 import pandas as pd
+from pydantic import Field
 
 from ixmp4.data import abstract
+
 from . import base
 from .docs import Docs, DocsRepository
 
@@ -16,8 +18,8 @@ class Model(base.BaseModel):
     id: int
     name: str
 
-    created_at: datetime | None
-    created_by: str | None
+    created_at: datetime | None = Field(None)
+    created_by: str | None = Field(None)
 
 
 class ModelRepository(
@@ -28,11 +30,10 @@ class ModelRepository(
 ):
     model_class = Model
     prefix = "models/"
-    enumeration_method = "PATCH"
 
-    def __init__(self, client, *args, **kwargs) -> None:
-        super().__init__(client, *args, **kwargs)
-        self.docs = ModelDocsRepository(self.client)
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.docs = ModelDocsRepository(self.backend)
 
     def create(
         self,
@@ -43,14 +44,14 @@ class ModelRepository(
     def get(self, name: str) -> Model:
         return super().get(name=name)
 
-    def list(self, *args, **kwargs) -> Iterable[Model]:
-        return super().list(*args, **kwargs)
+    def enumerate(self, **kwargs) -> list[Model] | pd.DataFrame:
+        return super().enumerate(**kwargs)
 
-    def tabulate(self, *args, **kwargs) -> pd.DataFrame:
-        return super().tabulate(*args, **kwargs)
+    def list(self, **kwargs) -> list[Model]:
+        return super()._list(json=kwargs)
 
-    def enumerate(self, *args, **kwargs) -> Iterable[Model] | pd.DataFrame:
-        return super().enumerate(*args, **kwargs)
+    def tabulate(self, **kwargs) -> pd.DataFrame:
+        return super()._tabulate(json=kwargs)
 
 
 class ModelDocsRepository(DocsRepository):
