@@ -1,11 +1,13 @@
-from typing import Iterable, ClassVar
 from datetime import datetime
+from typing import ClassVar
 
 import pandas as pd
+from pydantic import Field
 
 from ixmp4.data import abstract
-from .docs import DocsRepository, Docs
+
 from . import base
+from .docs import Docs, DocsRepository
 
 
 class Scenario(base.BaseModel):
@@ -15,8 +17,8 @@ class Scenario(base.BaseModel):
 
     id: int
     name: str
-    created_at: datetime | None
-    created_by: str | None
+    created_at: datetime | None = Field(None)
+    created_by: str | None = Field(None)
 
 
 class ScenarioDocsRepository(DocsRepository):
@@ -32,11 +34,10 @@ class ScenarioRepository(
 ):
     model_class = Scenario
     prefix = "scenarios/"
-    enumeration_method = "PATCH"
 
-    def __init__(self, client, *args, **kwargs) -> None:
-        super().__init__(client, *args, **kwargs)
-        self.docs = ScenarioDocsRepository(self.client)
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.docs = ScenarioDocsRepository(self.backend)
 
     def create(
         self,
@@ -47,11 +48,11 @@ class ScenarioRepository(
     def get(self, name: str) -> Scenario:
         return super().get(name=name)
 
-    def list(self, *args, **kwargs) -> Iterable[Scenario]:
-        return super().list(*args, **kwargs)
+    def enumerate(self, **kwargs) -> list[Scenario] | pd.DataFrame:
+        return super().enumerate(**kwargs)
 
-    def tabulate(self, *args, **kwargs) -> pd.DataFrame:
-        return super().tabulate(*args, **kwargs)
+    def list(self, **kwargs) -> list[Scenario]:
+        return super()._list(json=kwargs)
 
-    def enumerate(self, *args, **kwargs) -> Iterable[Scenario] | pd.DataFrame:
-        return super().enumerate(*args, **kwargs)
+    def tabulate(self, **kwargs) -> pd.DataFrame:
+        return super()._tabulate(json=kwargs)
