@@ -1,7 +1,7 @@
 from functools import wraps
-from typing import Protocol, Callable, TYPE_CHECKING
+from typing import TYPE_CHECKING, Callable, Protocol
 
-from ixmp4.core.exceptions import ProgrammingError, Forbidden
+from ixmp4.core.exceptions import Forbidden, ProgrammingError
 
 if TYPE_CHECKING:
     from ..backend.db import SqlAlchemyBackend
@@ -29,7 +29,8 @@ def guard(access: str) -> Callable:
                     return func(self, *args, **kwargs)
 
                 raise Forbidden(
-                    f"Function '{func.__name__}': '{access}' access denied due to insufficient permissions."
+                    f"Function '{func.__name__}': '{access}' access denied due to "
+                    "insufficient permissions."
                 )
             else:
                 # ignoring authorization since no auth context is set
