@@ -1,28 +1,41 @@
 """
 This module contains sqlalchemy database models and repositories.
 """
-# flake8: noqa
 
 from .base import BaseModel, BaseRepository
-from .unit import Unit, UnitRepository
-from .region import Region, RegionRepository
-from .iamc import (
-    Variable,
-    VariableRepository,
-    TimeSeriesRepository,
-    TimeSeries,
+from .docs import BaseDocsRepository, docs_model
+from .iamc import (  # AnnualDataPoint,; SubAnnualDataPoint,; CategoricalDataPoint,
+    DataPoint,
+    DataPointRepository,
     Measurand,
     MeasurandRepository,
-    DataPoint,
+    TimeSeries,
+    TimeSeriesRepository,
     UniversalDataPoint,
-    OracleDataPoint,
-    #    AnnualDataPoint,
-    #    SubAnnualDataPoint,
-    #    CategoricalDataPoint,
-    DataPointRepository,
+    Variable,
+    VariableRepository,
 )
-from .model import Model, ModelRepository
-from .run import Run, RunRepository
 from .meta import RunMetaEntry, RunMetaEntryRepository
+from .model import Model, ModelRepository
+from .optimization import (
+    Column,
+    ColumnRepository,
+    Equation,
+    EquationRepository,
+    IndexSet,
+    IndexSetRepository,
+    Parameter,
+    ParameterRepository,
+    Scalar,
+    ScalarRepository,
+    Table,
+    TableRepository,
+)
+
+# TODO for PR: avoiding name conflict here Is that okay?
+from .optimization import Variable as OptimizationVariable
+from .optimization import VariableRepository as OptimizationVariableRepository
+from .region import Region, RegionRepository
+from .run import Run, RunRepository
 from .scenario import Scenario, ScenarioRepository
-from .docs import docs_model, BaseDocsRepository
+from .unit import Unit, UnitRepository
