@@ -1,18 +1,15 @@
 from typing import ClassVar
 
-from ixmp4 import db
 from ixmp4.data import types
 from ixmp4.data.abstract import iamc as abstract
+from ixmp4.data.db import mixins
 
 from .. import base
 
 
-class Variable(base.BaseModel):
+class Variable(base.BaseModel, mixins.HasCreationInfo):
     NotFound: ClassVar = abstract.Variable.NotFound
     NotUnique: ClassVar = abstract.Variable.NotUnique
     DeletionPrevented: ClassVar = abstract.Variable.DeletionPrevented
 
-    name: types.String = db.Column(db.String(255), nullable=False, unique=True)
-
-    created_at: types.DateTime = db.Column(db.DateTime, nullable=True)
-    created_by: types.String = db.Column(db.String(255), nullable=True)
+    name: types.UniqueName
