@@ -1,10 +1,8 @@
-from typing import Iterable
-
 import pandas as pd
 
 from ixmp4 import db
-from ixmp4.data.auth.decorators import guard
 from ixmp4.data.abstract import iamc as abstract
+from ixmp4.data.auth.decorators import guard
 
 from .. import base
 from .docs import VariableDocsRepository
@@ -28,7 +26,7 @@ class VariableRepository(
         self.filter_class = VariableFilter
 
     def add(self, name: str) -> Variable:
-        variable = Variable(name=name, **self.get_creation_info())
+        variable = Variable(name=name)
         self.session.add(variable)
         return variable
 
@@ -45,7 +43,7 @@ class VariableRepository(
         return super().create(*args, **kwargs)
 
     @guard("view")
-    def list(self, *args, **kwargs) -> Iterable[Variable]:
+    def list(self, *args, **kwargs) -> list[Variable]:
         return super().list(*args, **kwargs)
 
     @guard("view")
