@@ -1,9 +1,7 @@
-from typing import Iterable
-
 from ixmp4.data import abstract
 
 from .. import base
-from ..docs import docs_model, BaseDocsRepository
+from ..docs import BaseDocsRepository, docs_model
 from .model import Model
 
 ModelDocs = docs_model(Model)
@@ -13,5 +11,5 @@ class ModelDocsRepository(BaseDocsRepository, base.BaseRepository):
     model_class = ModelDocs
     dimension_model_class = Model
 
-    def list(self, *, dimension_id: int | None = None) -> Iterable[abstract.Docs]:
+    def list(self, *, dimension_id: int | None = None) -> list[abstract.Docs]:
         return super().list(dimension_id=dimension_id)
