@@ -1,5 +1,3 @@
-from typing import Iterable
-
 import pandas as pd
 
 from ixmp4 import db
@@ -7,8 +5,8 @@ from ixmp4.data import abstract
 from ixmp4.data.auth.decorators import guard
 
 from .. import base
-from .model import Model
 from .docs import ModelDocsRepository
+from .model import Model
 
 
 class ModelRepository(
@@ -29,7 +27,7 @@ class ModelRepository(
         self.filter_class = ModelFilter
 
     def add(self, name: str) -> Model:
-        model = Model(name=name, **self.get_creation_info())
+        model = Model(name=name)
         self.session.add(model)
         return model
 
@@ -46,7 +44,7 @@ class ModelRepository(
         return super().create(*args, **kwargs)
 
     @guard("view")
-    def list(self, *args, **kwargs) -> Iterable[Model]:
+    def list(self, *args, **kwargs) -> list[Model]:
         return super().list(*args, **kwargs)
 
     @guard("view")
