@@ -1,11 +1,9 @@
-from typing import Iterable
-
 from ixmp4.data import abstract
 from ixmp4.data.auth.decorators import guard
 
-from ..docs import docs_model, BaseDocsRepository
-from .model import Region
 from .. import base
+from ..docs import BaseDocsRepository, docs_model
+from .model import Region
 
 RegionDocs = docs_model(Region)
 
@@ -15,5 +13,5 @@ class RegionDocsRepository(BaseDocsRepository, base.BaseRepository):
     dimension_model_class = Region
 
     @guard("view")
-    def list(self, *, dimension_id: int | None = None) -> Iterable[abstract.Docs]:
+    def list(self, *, dimension_id: int | None = None) -> list[abstract.Docs]:
         return super().list(dimension_id=dimension_id)
