@@ -28,36 +28,54 @@ directly using these commands:
    alembic revision -m "<message>" --autogenerate
 
 You will have to run all migrations before being able to create new ones
-in the development database. Be sure to run ``black`` on newly created
+in the development database. Be sure to run ``ruff`` on newly created
 migrations before committing them!
 
 """
-# flake8: noqa
+
+from typing import Annotated
 
 from sqlalchemy import (
-    sql,
-    UniqueConstraint,
     ForeignKey,
-    Sequence,
     Index,
-    select,
-    exists,
+    Sequence,
+    UniqueConstraint,
     delete,
-    update,
-    insert,
+    exists,
     func,
+    insert,
     or_,
+    select,
+    sql,
+    update,
 )
+from sqlalchemy.dialects.postgresql import JSONB
+from sqlalchemy.exc import IntegrityError, MultipleResultsFound
+from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import (
-    relationship,
-    backref,
+    Relationship,
     Session,
     aliased,
-    Relationship,
+    backref,
     mapped_column,
+    relationship,
 )
 from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy.types import *
+
 from . import utils
 
 Column = mapped_column
+IndexSetIdType = Annotated[
+    int,
+    Column(Integer, ForeignKey("optimization_indexset.id"), nullable=False, index=True),
+]
+JsonType = JSON()
+JsonType = JsonType.with_variant(JSONB(), "postgresql")
+NameType = Annotated[str, Column(String(255), nullable=False, unique=False)]
+RunIdType = Annotated[
+    int,
+    Column(Integer, ForeignKey("run.id"), nullable=False, index=True),
+]
+UniqueNameType = Annotated[str, Column(String(255), nullable=False, unique=True)]
+UsernameType = Annotated[str, Column(String(255), nullable=True)]
