@@ -1,13 +1,12 @@
-from fastapi import APIRouter, Depends, Query, Body, Path
+from fastapi import APIRouter, Body, Depends, Path, Query
 
-from ixmp4.data.backend import Backend
 from ixmp4.data import api
+from ixmp4.data.backend.db import SqlAlchemyBackend as Backend
 from ixmp4.data.db.unit.filter import UnitFilter
 
-from .decorators import autodoc
-from .base import BaseModel
 from . import deps
-
+from .base import BaseModel, EnumerationOutput, Pagination
+from .decorators import autodoc
 
 router: APIRouter = APIRouter(
     prefix="/units",
@@ -19,28 +18,24 @@ class UnitInput(BaseModel):
     name: str
 
 
-class EnumerationOutput(BaseModel):
-    __root__: api.DataFrame | list[api.Unit]
-
-
 @autodoc
-@router.get("/", response_model=EnumerationOutput)
-def enumerate(
-    filter: UnitFilter = Depends(),
-    table: bool | None = Query(False),
-    backend: Backend = Depends(deps.get_backend),
-):
-    return backend.units.enumerate(_filter=filter, table=bool(table))
-
-
-@autodoc
-@router.patch("/", response_model=EnumerationOutput)
+@router.patch("/", response_model=EnumerationOutput[api.Unit])
 def query(
     filter: UnitFilter = Body(None),
     table: bool = Query(False),
+    pagination: Pagination = Depends(),
     backend: Backend = Depends(deps.get_backend),
 ):
-    return backend.units.enumerate(_filter=filter, table=bool(table))
+    return EnumerationOutput(
+        results=backend.units.paginate(
+            _filter=filter,
+            limit=pagination.limit,
+            offset=pagination.offset,
+            table=bool(table),
+        ),
+        total=backend.units.count(_filter=filter),
+        pagination=pagination,
+    )
 
 
 @router.post("/", response_model=api.Unit)
@@ -48,12 +43,12 @@ def create(
     unit: UnitInput,
     backend: Backend = Depends(deps.get_backend),
 ):
-    return backend.units.create(**unit.dict())
+    return backend.units.create(**unit.model_dump())
 
 
 @router.delete("/{id}/")
 def delete(
-    id: int = Path(None),
+    id: int = Path(),
     backend: Backend = Depends(deps.get_backend),
 ):
     backend.units.delete(id)
